#version 150
precision highp float; precision highp int;
//Ethan Alexander Shulman 2022 "Non Absolutism" August 20, 2022

in vec3 in_Position;
out vec4 uv;
out float time;

layout(std140) uniform ShaderviewBlock {
	vec4 mouse;
	float screenX,screenY;
	int frame,framerate;
};

#define AA_SAMPLES 128

#define PI 3.141592653589793

mat2 r2d(float a) {
	float c = cos(a), s = sin(a);
	return mat2(c,s,-s,c);
}
//r2 hash http://extremelearning.com.au/unreasonable-effectiveness-of-quasirandom-sequences/
vec2 quasiRandom(float n) {
	#define R2V 1.32471795724474602596
	return fract(.5+n*(1./vec2(R2V,R2V*R2V)));
}


float line(vec2 p, vec2 a, vec2 b) {
	vec2 pa = p-a, ba = b-a;
	return length(pa-ba*clamp(dot(pa,ba)/dot(ba,ba),0.,1.));
}

vec3 hue(float h) {
	return clamp(abs(mod(h*6.+vec3(0.,4.,2.),6.)-3.)-1.,0.,1.);
}

uniform sampler2D Buffer0;

void vert() {
	//animation
	time = mod(float(frame)/float(framerate*AA_SAMPLES),60.);
	
	//time = 0.;//screenshots
	//time = 16.;
	
	uv = vec4((in_Position.xy*vec2(screenX/screenY,1)+(quasiRandom(float(frame%AA_SAMPLES))-.5)*2./screenY),
		(in_Position.xy*.5+.5)*vec2(screenX,screenY));
	gl_Position = vec4(in_Position,1);
}
void frag() {
	vec2 p = uv.xy;
	p = p*p*p*4.;
	float con = min(1.,time/45.), icon = 1.-con;
	for (int i = 0; i < 26; i++) {
		vec2 tp = vec2(0,p.y);
		tp *= r2d(p.x+time/60.*PI*4.*(con+icon*float(i)/25.));
		p.y = tp.y;
		p.x += tp.x*p.x;
	}
	vec3 c = vec3(mod(floor(p.x)+floor(p.y),2.));
	
	vec4 sum = texelFetch(Buffer0,ivec2(uv.zw),0);
	if (frame%AA_SAMPLES == 0) sum = vec4(0);
	sum += vec4(c, 1.);
	gl_FragColor = sum;
}
